@@ -17,7 +17,7 @@
 // Copyright (C) 2005-2007 Jeff Muizelaar <jeff@infidigm.net>
 // Copyright (C) 2005, 2006 Kristian Høgsberg <krh@redhat.com>
 // Copyright (C) 2005 Martin Kretzschmar <martink@gnome.org>
-// Copyright (C) 2005, 2009, 2012, 2013, 2015, 2017, 2018 Albert Astals Cid <aacid@kde.org>
+// Copyright (C) 2005, 2009, 2012, 2013, 2015, 2017-2019 Albert Astals Cid <aacid@kde.org>
 // Copyright (C) 2006, 2007, 2010, 2011 Carlos Garcia Campos <carlosgc@gnome.org>
 // Copyright (C) 2007 Koji Otani <sho@bbr.jp>
 // Copyright (C) 2008, 2009 Chris Wilson <chris@chris-wilson.co.uk>
@@ -29,6 +29,7 @@
 // Copyright (C) 2013 Thomas Freitag <Thomas.Freitag@alfa.de>
 // Copyright (C) 2015, 2016 Jason Crain <jason@aquaticape.us>
 // Copyright (C) 2018 Adam Reichold <adam.reichold@t-online.de>
+// Copyright (C) 2019 Christian Persch <chpe@src.gnome.org>
 //
 // To see a description of the changes please see the Changelog file that
 // came with your tarball or type make ChangeLog if you are building from git
@@ -64,7 +65,7 @@
 CairoFont::CairoFont(Ref refA,
 		     cairo_font_face_t *cairo_font_faceA,
 		     int *codeToGIDA,
-		     Guint codeToGIDLenA,
+		     unsigned int codeToGIDLenA,
 		     bool substituteA,
 		     bool printingA) : ref(refA),
 				       cairo_font_face(cairo_font_faceA),
@@ -80,7 +81,7 @@ CairoFont::~CairoFont() {
 
 bool
 CairoFont::matches(Ref &other, bool printingA) {
-  return (other.num == ref.num && other.gen == ref.gen);
+  return (other == ref);
 }
 
 cairo_font_face_t *
@@ -280,7 +281,7 @@ _ft_new_face (FT_Library lib,
 
   if (font_data == nullptr) {
     /* if we fail to mmap the file, just pass it to FreeType instead */
-    tmpl.fd = open (filename, O_RDONLY);
+    tmpl.fd = openFileDescriptor (filename, O_RDONLY);
     if (tmpl.fd == -1)
       return _ft_new_face_uncached (lib, filename, font_data, font_data_len, face_out, font_face_out);
 
@@ -373,7 +374,7 @@ _ft_new_face (FT_Library lib,
 CairoFreeTypeFont::CairoFreeTypeFont(Ref refA,
 				     cairo_font_face_t *cairo_font_faceA,
 				     int *codeToGIDA,
-				     Guint codeToGIDLenA,
+				     unsigned int codeToGIDLenA,
 				     bool substituteA) : CairoFont(refA,
 								   cairo_font_faceA,
 								   codeToGIDA,
@@ -401,7 +402,7 @@ CairoFreeTypeFont *CairoFreeTypeFont::create(GfxFont *gfxFont, XRef *xref,
   cairo_font_face_t *font_face;
 
   int *codeToGID;
-  Guint codeToGIDLen;
+  unsigned int codeToGIDLen;
   
   codeToGID = nullptr;
   codeToGIDLen = 0;
@@ -729,7 +730,7 @@ CairoType3Font *CairoType3Font::create(GfxFont *gfxFont, PDFDoc *doc,
   cairo_font_face_t *font_face;
   Ref ref;
   int *codeToGID;
-  Guint codeToGIDLen;
+  unsigned int codeToGIDLen;
   int i, j;
   char **enc;
   Dict *charProcs;
@@ -770,7 +771,7 @@ CairoType3Font *CairoType3Font::create(GfxFont *gfxFont, PDFDoc *doc,
 CairoType3Font::CairoType3Font(Ref refA,
 			       cairo_font_face_t *cairo_font_faceA,
 			       int *codeToGIDA,
-			       Guint codeToGIDLenA,
+			       unsigned int codeToGIDLenA,
 			       bool printingA, XRef *xref) : CairoFont(refA,
 							   cairo_font_faceA,
 							   codeToGIDA,
@@ -783,7 +784,7 @@ CairoType3Font::~CairoType3Font() { }
 
 bool
 CairoType3Font::matches(Ref &other, bool printingA) {
-  return (other.num == ref.num && other.gen == ref.gen && printing == printingA);
+  return (other == ref && printing == printingA);
 }
 
 
