@@ -24,7 +24,6 @@
 #ifndef DATE_INFO_H
 #define DATE_INFO_H
 
-#include "goo/gtypes.h"
 #include "goo/GooString.h"
 #include <time.h>
 
@@ -32,6 +31,7 @@ bool parseDateString(const char *string, int *year, int *month, int *day, int *h
 
 /* Converts the time_t into a PDF Date format string.
  * If timet is NULL, current time is used.
+ * Returns new GooString. Free with delete.
  */
 GooString *timeToDateString(time_t *timet);
 
