@@ -15,7 +15,7 @@
 //
 // Copyright (C) 2007 Julien Rebetez <julienr@svn.gnome.org>
 // Copyright (C) 2008 Kees Cook <kees@outflux.net>
-// Copyright (C) 2008, 2010, 2017, 2018 Albert Astals Cid <aacid@kde.org>
+// Copyright (C) 2008, 2010, 2017-2019 Albert Astals Cid <aacid@kde.org>
 // Copyright (C) 2009 Jakub Wilk <jwilk@jwilk.net>
 // Copyright (C) 2012 Fabio D'Urso <fabiodurso@hotmail.it>
 // Copyright (C) 2013 Thomas Freitag <Thomas.Freitag@alfa.de>
@@ -38,7 +38,6 @@
 #include <stdio.h>
 #include <string.h>
 #include <limits.h>
-#include "goo/gtypes.h"
 #include "goo/gmem.h"
 #include "goo/GooString.h"
 #include "goo/GooLikely.h"
@@ -83,13 +82,19 @@ class Stream;
 struct Ref {
   int num;			// object number
   int gen;			// generation number
+
+  static constexpr Ref INVALID() { return {-1, -1}; };
 };
 
-inline bool operator== (const Ref& lhs, const Ref& rhs) noexcept {
+inline bool operator== (const Ref lhs, const Ref rhs) noexcept {
   return lhs.num == rhs.num && lhs.gen == rhs.gen;
 }
 
-inline bool operator< (const Ref& lhs, const Ref& rhs) noexcept {
+inline bool operator!= (const Ref lhs, const Ref rhs) noexcept {
+  return lhs.num != rhs.num || lhs.gen != rhs.gen;
+}
+
+inline bool operator< (const Ref lhs, const Ref rhs) noexcept {
   if (lhs.num != rhs.num)
     return lhs.num < rhs.num;
   return lhs.gen < rhs.gen;
@@ -104,7 +109,7 @@ struct hash<Ref>
     using argument_type = Ref;
     using result_type = size_t;
 
-    result_type operator() (const argument_type &ref) const noexcept
+    result_type operator() (const argument_type ref) const noexcept
     {
 	return std::hash<int>{}(ref.num) ^ (std::hash<int>{}(ref.gen) << 1);
     }
@@ -173,8 +178,8 @@ public:
     { assert(dictA); type = objDict; dict = dictA; }
   explicit Object(Stream *streamA)
     { assert(streamA); type = objStream; stream = streamA; }
-  Object(int numA, int genA)
-    { type = objRef; ref.num = numA; ref.gen = genA; }
+  explicit Object(const Ref r)
+    { type = objRef; ref = r; }
 
   template<typename T> Object(T) = delete;
 
@@ -271,7 +276,7 @@ public:
   void arrayAdd(Object &&elem);
   void arrayRemove(int i);
   Object arrayGet(int i, int recursion) const;
-  Object arrayGetNF(int i) const;
+  const Object &arrayGetNF(int i) const;
 
   // Dict accessors.
   int dictGetLength() const;
@@ -281,17 +286,17 @@ public:
   void dictRemove(const char *key);
   bool dictIs(const char *dictType) const;
   Object dictLookup(const char *key, int recursion = 0) const;
-  Object dictLookupNF(const char *key) const;
+  const Object &dictLookupNF(const char *key) const;
   const char *dictGetKey(int i) const;
   Object dictGetVal(int i) const;
-  Object dictGetValNF(int i) const;
+  const Object &dictGetValNF(int i) const;
 
   // Stream accessors.
   bool streamIs(const char *dictType) const;
   void streamReset();
   void streamClose();
   int streamGetChar() const;
-  int streamGetChars(int nChars, Guchar *buffer) const;
+  int streamGetChars(int nChars, unsigned char *buffer) const;
   int streamLookChar() const;
   char *streamGetLine(char *buf, int size) const;
   Goffset streamGetPos() const;
@@ -339,7 +344,7 @@ inline void Object::arrayRemove(int i)
 inline Object Object::arrayGet(int i, int recursion = 0) const
   { OBJECT_TYPE_CHECK(objArray); return array->get(i, recursion); }
 
-inline Object Object::arrayGetNF(int i) const
+inline const Object &Object::arrayGetNF(int i) const
   { OBJECT_TYPE_CHECK(objArray); return array->getNF(i); }
 
 //------------------------------------------------------------------------
@@ -369,7 +374,7 @@ inline bool Object::isDict(const char *dictType) const
 inline Object Object::dictLookup(const char *key, int recursion) const
   { OBJECT_TYPE_CHECK(objDict); return dict->lookup(key, recursion); }
 
-inline Object Object::dictLookupNF(const char *key) const
+inline const Object &Object::dictLookupNF(const char *key) const
   { OBJECT_TYPE_CHECK(objDict); return dict->lookupNF(key); }
 
 inline const char *Object::dictGetKey(int i) const
@@ -378,7 +383,7 @@ inline const char *Object::dictGetKey(int i) const
 inline Object Object::dictGetVal(int i) const
   { OBJECT_TYPE_CHECK(objDict); return dict->getVal(i); }
 
-inline Object Object::dictGetValNF(int i) const
+inline const Object &Object::dictGetValNF(int i) const
   { OBJECT_TYPE_CHECK(objDict); return dict->getValNF(i); }
 
 //------------------------------------------------------------------------
@@ -402,7 +407,7 @@ inline void Object::streamClose()
 inline int Object::streamGetChar() const
   { OBJECT_TYPE_CHECK(objStream); return stream->getChar(); }
 
-inline int Object::streamGetChars(int nChars, Guchar *buffer) const
+inline int Object::streamGetChars(int nChars, unsigned char *buffer) const
   { OBJECT_TYPE_CHECK(objStream); return stream->doGetChars(nChars, buffer); }
 
 inline int Object::streamLookChar() const
