@@ -7,14 +7,16 @@
 // Copyright 2015 André Guerreiro <aguerreiro1985@gmail.com>
 // Copyright 2015 André Esser <bepandre@hotmail.com>
 // Copyright 2017 Hans-Ulrich Jüttner <huj@froreich-bioscientia.de>
-// Copyright 2017, 2018 Albert Astals Cid <aacid@kde.org>
+// Copyright 2017-2019 Albert Astals Cid <aacid@kde.org>
 // Copyright 2018 Chinmoy Ranjan Pradhan <chinmoyrp65@protonmail.com>
+// Copyright 2018 Oliver Sander <oliver.sander@tu-dresden.de>
 //
 //========================================================================
 
 #include <config.h>
 
 #include "SignatureInfo.h"
+#include "CertificateInfo.h"
 #include "goo/gmem.h"
 #include <stdlib.h>
 #include <string.h>
@@ -31,6 +33,7 @@ SignatureInfo::SignatureInfo()
 {
   sig_status = SIGNATURE_NOT_VERIFIED;
   cert_status = CERTIFICATE_NOT_VERIFIED;
+  cert_info = nullptr;
   signer_name = nullptr;
   subject_dn = nullptr;
   location = nullptr;
@@ -44,6 +47,7 @@ SignatureInfo::SignatureInfo(SignatureValidationStatus sig_val_status, Certifica
 {
   sig_status = sig_val_status;
   cert_status = cert_val_status;
+  cert_info = nullptr;
   signer_name = nullptr;
   subject_dn = nullptr;
   location = nullptr;
@@ -103,6 +107,11 @@ time_t SignatureInfo::getSigningTime()
   return signing_time;
 }
 
+const X509CertificateInfo *SignatureInfo::getCertificateInfo() const
+{
+  return cert_info.get();
+}
+
 /* SETTERS */
 
 void SignatureInfo::setSignatureValStatus(enum SignatureValidationStatus sig_val_status)
@@ -124,7 +133,7 @@ void SignatureInfo::setSignerName(char *signerName)
 void SignatureInfo::setSubjectDN(const char *subjectDN)
 {
   free(subject_dn);
-  subject_dn = strdup(subjectDN);
+  subject_dn = subjectDN ? strdup(subjectDN) : nullptr;
 }
 
 void SignatureInfo::setLocation(const char *loc)
@@ -148,3 +157,8 @@ void SignatureInfo::setSigningTime(time_t signingTime)
 {
   signing_time = signingTime;
 }
+
+void SignatureInfo::setCertificateInfo(std::unique_ptr<X509CertificateInfo> certInfo)
+{
+  cert_info = std::move(certInfo);
+}
