@@ -15,7 +15,7 @@
 //
 // Copyright (C) 2005 Jeff Muizelaar <jeff@infidigm.net>
 // Copyright (C) 2008 Julien Rebetez <julien@fhtagn.net>
-// Copyright (C) 2008, 2010, 2011, 2016-2018 Albert Astals Cid <aacid@kde.org>
+// Copyright (C) 2008, 2010, 2011, 2016-2019 Albert Astals Cid <aacid@kde.org>
 // Copyright (C) 2009 Carlos Garcia Campos <carlosgc@gnome.org>
 // Copyright (C) 2009 Stefan Thomas <thomas@eload24.com>
 // Copyright (C) 2010 Hib Eris <hib@hiberis.nl>
@@ -39,7 +39,6 @@
 #include <cstdio>
 
 #include "poppler-config.h"
-#include "goo/gtypes.h"
 #include "Object.h"
 
 class GooFile;
@@ -85,8 +84,8 @@ enum CryptAlgorithm {
 //------------------------------------------------------------------------
 
 typedef struct _ByteRange {
-  Guint offset;
-  Guint length;
+  unsigned int offset;
+  unsigned int length;
 } ByteRange;
 
 //------------------------------------------------------------------------
@@ -114,7 +113,7 @@ public:
   // Close down the stream.
   virtual void close();
 
-  inline int doGetChars(int nChars, Guchar *buffer)
+  inline int doGetChars(int nChars, unsigned char *buffer)
   {
     if (hasGetChars()) {
       return getChars(nChars, buffer);
@@ -130,7 +129,7 @@ public:
 
   inline void fillGooString(GooString *s)
   {
-    Guchar readBuf[4096];
+    unsigned char readBuf[4096];
     int readChars;
     reset();
     while ((readChars = doGetChars(4096, readBuf)) != 0) {
@@ -138,10 +137,10 @@ public:
     }
   }
   
-  inline Guchar *toUnsignedChars(int *length, int initialSize = 4096, int sizeIncrement = 4096)
+  inline unsigned char *toUnsignedChars(int *length, int initialSize = 4096, int sizeIncrement = 4096)
   {
     int readChars;
-    Guchar *buf = (Guchar *)gmalloc(initialSize);
+    unsigned char *buf = (unsigned char *)gmalloc(initialSize);
     int size = initialSize;
     *length = 0;
     int charsToRead = initialSize;
@@ -153,7 +152,7 @@ public:
         if (lookChar() != EOF) {
           size += sizeIncrement;
           charsToRead = sizeIncrement;
-          buf = (Guchar *)grealloc(buf, size);
+          buf = (unsigned char *)grealloc(buf, size);
         } else {
           continueReading = false;
         }
@@ -233,7 +232,7 @@ private:
   int decRef() { return --ref; }
 
   virtual bool hasGetChars() { return false; }
-  virtual int getChars(int nChars, Guchar *buffer);
+  virtual int getChars(int nChars, unsigned char *buffer);
 
   Stream *makeFilter(const char *name, Stream *str, Object *params, int recursion = 0, Dict *dict = nullptr);
 
@@ -379,11 +378,11 @@ public:
 
   // Gets the next pixel from the stream.  <pix> should be able to hold
   // at least nComps elements.  Returns false at end of file.
-  bool getPixel(Guchar *pix);
+  bool getPixel(unsigned char *pix);
 
   // Returns a pointer to the next line of pixels.  Returns NULL at
   // end of file.
-  Guchar *getLine();
+  unsigned char *getLine();
 
   // Skip an entire line from the image.
   void skipLine();
@@ -396,8 +395,8 @@ private:
   int nBits;			// bits per component
   int nVals;			// components per line
   int inputLineSize;		// input line buffer size
-  Guchar *inputLine;		// input line buffer
-  Guchar *imgLine;		// line buffer
+  unsigned char *inputLine;		// input line buffer
+  unsigned char *imgLine;		// line buffer
   int imgIdx;			// current index in imgLine
 };
 
@@ -422,7 +421,7 @@ public:
 
   int lookChar();
   int getChar();
-  int getChars(int nChars, Guchar *buffer);
+  int getChars(int nChars, unsigned char *buffer);
 
 private:
 
@@ -436,7 +435,7 @@ private:
   int nVals;			// components per line
   int pixBytes;			// bytes per pixel
   int rowBytes;			// bytes per line
-  Guchar *predLine;		// line buffer
+  unsigned char *predLine;		// line buffer
   int predIdx;			// current index in predLine
   bool ok;
 };
@@ -471,12 +470,15 @@ public:
   int getUnfilteredChar () override { return getChar(); }
   void unfilteredReset () override { reset(); }
 
+  bool getNeedsEncryptionOnSave() const { return needsEncryptionOnSave; }
+  void setNeedsEncryptionOnSave(bool needsEncryptionOnSaveA) { needsEncryptionOnSave = needsEncryptionOnSaveA; }
+
 private:
 
   bool fillBuf();
   
   bool hasGetChars() override { return true; }
-  int getChars(int nChars, Guchar *buffer) override
+  int getChars(int nChars, unsigned char *buffer) override
     {
       int n, m;
 
@@ -509,6 +511,8 @@ private:
   Goffset bufPos;
   Goffset savePos;
   bool saved;
+  bool needsEncryptionOnSave;   // Needed for FileStreams that point to "external" files
+                                // and thus when saving we can't do a raw copy
 };
 
 //------------------------------------------------------------------------
@@ -551,7 +555,7 @@ private:
   char buf[cachedStreamBufSize];
   char *bufPtr;
   char *bufEnd;
-  Guint bufPos;
+  unsigned int bufPos;
   int savePos;
   bool saved;
 };
@@ -605,7 +609,7 @@ public:
   Goffset getPos() override { return (int)(bufPtr - buf); }
 
   void setPos(Goffset pos, int dir = 0) override {
-    Guint i;
+    unsigned int i;
 
     if (dir >= 0) {
       i = pos;
@@ -639,7 +643,7 @@ private:
 
   bool hasGetChars() override { return true; }
 
-  int getChars(int nChars, Guchar *buffer) override {
+  int getChars(int nChars, unsigned char *buffer) override {
     int n;
 
     if (nChars <= 0) {
@@ -716,7 +720,7 @@ public:
 private:
 
   bool hasGetChars() override { return true; }
-  int getChars(int nChars, Guchar *buffer) override;
+  int getChars(int nChars, unsigned char *buffer) override;
 
   Stream *str;
   bool limited;
@@ -800,7 +804,7 @@ public:
 private:
 
   bool hasGetChars() override { return true; }
-  int getChars(int nChars, Guchar *buffer) override;
+  int getChars(int nChars, unsigned char *buffer) override;
 
   inline int doGetRawChar() {
     if (eof) {
@@ -822,13 +826,13 @@ private:
   struct {			// decoding table
     int length;
     int head;
-    Guchar tail;
+    unsigned char tail;
   } table[4097];
   int nextCode;			// next code to be used
   int nextBits;			// number of bits in next code word
   int prevCode;			// previous code used in stream
   int newChar;			// next char to be added to table
-  Guchar seqBuf[4097];		// buffer for current sequence
+  unsigned char seqBuf[4097];		// buffer for current sequence
   int seqLength;		// length of current sequence
   int seqIndex;			// index into current sequence
   bool first;			// first code after a table clear
@@ -859,7 +863,7 @@ public:
 private:
 
   bool hasGetChars() override { return true; }
-  int getChars(int nChars, Guchar *buffer) override;
+  int getChars(int nChars, unsigned char *buffer) override;
 
   char buf[128];		// buffer
   char *bufPtr;			// next char to read
@@ -914,7 +918,7 @@ private:
   bool eof;			// true if at eof
   bool nextLine2D;		// true if next line uses 2D encoding
   int row;			// current row
-  Guint inputBuf;		// input buffer
+  unsigned int inputBuf;		// input buffer
   int inputBits;		// number of bits in input buffer
   int *codingLine;		// coding line changing elements
   int *refLine;			// reference line changing elements
@@ -957,10 +961,10 @@ struct DCTScanInfo {
 
 // DCT Huffman decoding table
 struct DCTHuffTable {
-  Guchar firstSym[17];		// first symbol for this bit length
-  Gushort firstCode[17];	// first code for this bit length
-  Gushort numCodes[17];		// number of codes of this bit length
-  Guchar sym[256];		// symbols
+  unsigned char firstSym[17];		// first symbol for this bit length
+  unsigned short firstCode[17];	// first code for this bit length
+  unsigned short numCodes[17];		// number of codes of this bit length
+  unsigned char sym[256];		// symbols
 };
 
 class DCTStream: public FilterStream {
@@ -995,13 +999,13 @@ private:
   bool gotJFIFMarker;		// set if APP0 JFIF marker was present
   bool gotAdobeMarker;		// set if APP14 Adobe marker was present
   int restartInterval;		// restart interval, in MCUs
-  Gushort quantTables[4][64];	// quantization tables
+  unsigned short quantTables[4][64];	// quantization tables
   int numQuantTables;		// number of quantization tables
   DCTHuffTable dcHuffTables[4];	// DC Huffman tables
   DCTHuffTable acHuffTables[4];	// AC Huffman tables
   int numDCHuffTables;		// number of DC Huffman tables
   int numACHuffTables;		// number of AC Huffman tables
-  Guchar *rowBuf[4][32];	// buffer for one MCU (non-progressive mode)
+  unsigned char *rowBuf[4][32];	// buffer for one MCU (non-progressive mode)
   int *frameBuf[4];		// buffer for frame (progressive mode)
   int comp, x, y, dy;		// current position within image/MCU
   int restartCtr;		// MCUs left until restart
@@ -1020,8 +1024,8 @@ private:
 				DCTHuffTable *acHuffTable,
 				int *prevDC, int data[64]);
   void decodeImage();
-  void transformDataUnit(Gushort *quantTable,
-			 int dataIn[64], Guchar dataOut[64]);
+  void transformDataUnit(unsigned short *quantTable,
+			 int dataIn[64], unsigned char dataOut[64]);
   int readHuffSym(DCTHuffTable *table);
   int readAmp(int size);
   int readBit();
@@ -1055,8 +1059,8 @@ private:
 
 // Huffman code table entry
 struct FlateCode {
-  Gushort len;			// code length, in bits
-  Gushort val;			// value represented by this code
+  unsigned short len;			// code length, in bits
+  unsigned short val;			// value represented by this code
 };
 
 struct FlateHuffmanTab {
@@ -1103,10 +1107,10 @@ private:
   }
 
   bool hasGetChars() override { return true; }
-  int getChars(int nChars, Guchar *buffer) override;
+  int getChars(int nChars, unsigned char *buffer) override;
 
   StreamPredictor *pred;	// predictor
-  Guchar buf[flateWindow];	// output data buffer
+  unsigned char buf[flateWindow];	// output data buffer
   int index;			// current index into output buffer
   int remain;			// number valid bytes in output buffer
   int codeBuf;			// input buffer
@@ -1325,7 +1329,7 @@ private:
   LZWEncoderNode table[4096];
   int nextSeq;
   int codeLen;
-  Guchar inBuf[4096];
+  unsigned char inBuf[4096];
   int inBufLen;
   int outBuf;
   int outBufLen;
