@@ -23,6 +23,8 @@
 // Copyright (C) 2013 Thomas Freitag <Thomas.Freitag@alfa.de>
 // Copyright (C) 2018 Klarälvdalens Datakonsult AB, a KDAB Group company, <info@kdab.com>. Work sponsored by the LiMux project of the city of Munich
 // Copyright (C) 2018 Sanchit Anand <sanxchit@gmail.com>
+// Copyright (C) 2018 Nelson Benítez León <nbenitezl@gmail.com>
+// Copyright (C) 2019 Oliver Sander <oliver.sander@tu-dresden.de>
 //
 // To see a description of the changes please see the Changelog file that
 // came with your tarball or type make ChangeLog if you are building from git
@@ -34,13 +36,11 @@
 
 #include "poppler-config.h"
 #include <stdio.h>
-#include "goo/gtypes.h"
 #include "GfxFont.h"
 #include "GfxState.h"
 #include "OutputDev.h"
 
 class GooString;
-class GooList;
 class Gfx;
 class GfxFont;
 class GfxState;
@@ -53,6 +53,8 @@ class TextLine;
 class TextLineFrag;
 class TextBlock;
 class TextFlow;
+class TextLink;
+class TextUnderline;
 class TextWordList;
 class TextPage;
 class TextSelectionVisitor;
@@ -341,6 +343,9 @@ private:
   Unicode *normalized;		// normalized form of Unicode text
   int normalized_len;		// number of normalized Unicode chars
   int *normalized_idx;		// indices of normalized chars into Unicode text
+  Unicode *ascii_translation;	// ascii translation from the normalized text
+  int ascii_len;		// length of ascii translation text
+  int *ascii_idx;		// indices of ascii chars into Unicode text of line
 
   friend class TextLineFrag;
   friend class TextBlock;
@@ -515,7 +520,7 @@ public:
 
 private:
 
-  GooList *words;			// [TextWord]
+  std::vector<TextWord*> *words;
 };
 
 #endif // TEXTOUT_WORD_LIST
@@ -606,6 +611,18 @@ public:
 		 double *xMin, double *yMin,
 		 double *xMax, double *yMax);
 
+  // Adds new parameter ignoreDiacritics, which will do diacritics
+  // insensitive search, i.e. ignore accents, umlauts, diaeresis,etc.
+  // while matching. This option will be ignored if <s> contains characters
+  // which are not pure ascii.
+  bool findText(Unicode *s, int len,
+		 bool startAtTop, bool stopAtBottom,
+		 bool startAtLast, bool stopAtLast,
+		 bool caseSensitive, bool ignoreDiacritics,
+		 bool backward, bool wholeWord,
+		 double *xMin, double *yMin,
+		 double *xMax, double *yMax);
+
   // Get the text which is inside the specified rectangle.
   GooString *getText(double xMin, double yMin,
 		     double xMax, double yMax);
@@ -621,14 +638,14 @@ public:
 		     SelectionStyle style,
 		     GfxColor *glyph_color, GfxColor *box_color);
 
-  GooList *getSelectionRegion(PDFRectangle *selection,
+  std::vector<PDFRectangle*> *getSelectionRegion(PDFRectangle *selection,
 			      SelectionStyle style,
 			      double scale);
 
   GooString *getSelectionText(PDFRectangle *selection,
 			      SelectionStyle style);
 
-  GooList **getSelectionWords(PDFRectangle *selection,
+  std::vector<TextWordSelection*> **getSelectionWords(PDFRectangle *selection,
                               SelectionStyle style,
                               int *nLines);
 
@@ -693,15 +710,14 @@ private:
 				//   rawOrder is set)
   TextWord *rawLastWord;	// last word on rawWords list
 
-  GooList *fonts;			// all font info objects used on this
-				//   page [TextFontInfo]
+  std::vector<TextFontInfo*> *fonts;// all font info objects used on this page
 
   double lastFindXMin,		// coordinates of the last "find" result
          lastFindYMin;
   bool haveLastFind;
 
-  GooList *underlines;		// [TextUnderline]
-  GooList *links;		// [TextLink]
+  std::vector<TextUnderline*> *underlines;
+  std::vector<TextLink*> *links;
 
   int refCnt;
 
@@ -861,7 +877,7 @@ public:
 		     SelectionStyle style,
 		     GfxColor *glyph_color, GfxColor *box_color);
 
-  GooList *getSelectionRegion(PDFRectangle *selection,
+  std::vector<PDFRectangle*> *getSelectionRegion(PDFRectangle *selection,
 			      SelectionStyle style,
 			      double scale);
 
