@@ -1,5 +1,5 @@
 /* poppler-embeddedfile-private.h: Qt interface to poppler
- * Copyright (C) 2005, 2008, 2009, 2012, Albert Astals Cid <aacid@kde.org>
+ * Copyright (C) 2005, 2008, 2009, 2012, 2018, Albert Astals Cid <aacid@kde.org>
  * Copyright (C) 2005, Brad Hards <bradh@frogmouth.net>
  * Copyright (C) 2008, 2011, Pino Toscano <pino@kde.org>
  *
@@ -31,6 +31,9 @@ class EmbeddedFileData
 public:
 	EmbeddedFileData(FileSpec *fs);
 	~EmbeddedFileData();
+
+	EmbeddedFileData(const EmbeddedFileData &) = delete;
+	EmbeddedFileData& operator=(const EmbeddedFileData &) = delete;
     
 	EmbFile *embFile() const;
 
