@@ -14,6 +14,7 @@
  * Copyright (C) 2018 Klarälvdalens Datakonsult AB, a KDAB Group company, <info@kdab.com>. Work sponsored by the LiMux project of the city of Munich
  * Copyright (C) 2018 Adam Reichold <adam.reichold@t-online.de>
  * Copyright (C) 2019 Oliver Sander <oliver.sander@tu-dresden.de>
+ * Copyright (C) 2019 João Netto <joaonetto901@gmail.com>
  * Inspired on code by
  * Copyright (C) 2004 by Albert Astals Cid <tsdgeos@terra.es>
  * Copyright (C) 2004 by Enrico Ros <eros.kde@email.it>
@@ -237,6 +238,14 @@ namespace Poppler {
 		::FormWidget *fm;
 		QRectF box;
     };
+    
+    class FormFieldIcon;
+    class FormFieldIconData
+    {
+    public:
+    	static FormFieldIconData *getData( const FormFieldIcon &f );
+    	Dict *icon;
+    };
 
 }
 
