@@ -1,7 +1,7 @@
 /* poppler-qt.h: qt interface to poppler
  * Copyright (C) 2005, Net Integration Technologies, Inc.
  * Copyright (C) 2005, 2007, Brad Hards <bradh@frogmouth.net>
- * Copyright (C) 2005-2015, 2017, Albert Astals Cid <aacid@kde.org>
+ * Copyright (C) 2005-2015, 2017-2019, Albert Astals Cid <aacid@kde.org>
  * Copyright (C) 2005, Stefan Kebekus <stefan.kebekus@math.uni-koeln.de>
  * Copyright (C) 2006-2011, Pino Toscano <pino@kde.org>
  * Copyright (C) 2009 Shawn Rutledge <shawn.t.rutledge@gmail.com>
@@ -12,12 +12,13 @@
  * Copyright (C) 2012, Guillermo A. Amaral B. <gamaral@kde.org>
  * Copyright (C) 2012, Fabio D'Urso <fabiodurso@hotmail.it>
  * Copyright (C) 2012, Tobias Koenig <tobias.koenig@kdab.com>
- * Copyright (C) 2012, 2014, 2015 Adam Reichold <adamreichold@myopera.com>
+ * Copyright (C) 2012, 2014, 2015, 2018, 2019 Adam Reichold <adamreichold@myopera.com>
  * Copyright (C) 2012, 2013 Thomas Freitag <Thomas.Freitag@alfa.de>
  * Copyright (C) 2013 Anthony Granger <grangeranthony@gmail.com>
  * Copyright (C) 2016 Jakub Alba <jakubalba@gmail.com>
  * Copyright (C) 2017 Oliver Sander <oliver.sander@tu-dresden.de>
  * Copyright (C) 2017, 2018 Klarälvdalens Datakonsult AB, a KDAB Group company, <info@kdab.com>. Work sponsored by the LiMux project of the city of Munich
+ * Copyright (C) 2018 Nelson Benítez León <nbenitezl@gmail.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -69,6 +70,8 @@ namespace Poppler {
     class PDFConverter;
     class PSConverter;
 
+    struct OutlineItemData;
+
     /**
 	Debug/error function.
 
@@ -202,7 +205,7 @@ namespace Poppler {
 	~FontInfo();
 
 	/**
-	   The name of the font. Can be QString::null if the font has no name
+	   The name of the font. Can be a null QString if the font has no name
 	*/
 	QString name() const;
 
@@ -739,7 +742,10 @@ delete it;
         {
             NoSearchFlags = 0x00000000, ///< since 0.63
             IgnoreCase = 0x00000001,    ///< Case differences are ignored
-            WholeWords = 0x00000002    ///< Only whole words are matched
+            WholeWords = 0x00000002,    ///< Only whole words are matched
+            IgnoreDiacritics = 0x00000004    ///< Diacritic differences (eg. accents, umlauts, diaeresis) are ignored. \since 0.73
+                                             ///< This option will have no effect if the search term contains characters which
+                                             ///< are not pure ascii.
         };
         Q_DECLARE_FLAGS( SearchFlags, SearchFlag )
 	
@@ -960,6 +966,13 @@ delete it;
 	**/
 	QString label() const;
 	
+	/**
+	   Returns the index of the page.
+
+	 \since 0.70
+	**/
+	int index() const;
+
     private:
 	Q_DISABLE_COPY(Page)
 
@@ -967,6 +980,83 @@ delete it;
 	PageData *m_page;
     };
 
+    /**
+       \brief Item in the outline of a PDF document
+
+       Represents an item in the outline of PDF document, i.e. a name, an internal or external link and a set of child items.
+
+       \since 0.74
+    **/
+    class POPPLER_QT5_EXPORT OutlineItem {
+      friend class Document;
+    public:
+      /**
+	 Constructs a null item, i.e. one that does not represent a valid item in the outline of some PDF document.
+      **/
+      OutlineItem();
+      ~OutlineItem();
+
+      OutlineItem(const OutlineItem &other);
+      OutlineItem &operator=(const OutlineItem &other);
+
+      OutlineItem(OutlineItem &&other);
+      OutlineItem &operator=(OutlineItem &&other);
+
+      /**
+	 Indicates whether an item is null, i.e. whether it does not represent a valid item in the outline of some PDF document.
+      **/
+      bool isNull() const;
+
+      /**
+	 The name of the item which should be displayed to the user.
+      **/
+      QString name() const;
+
+      /**
+	 Indicates whether the item should initially be display in an expanded or collapsed state.
+      **/
+      bool isOpen() const;
+
+      /**
+	 The destination referred to by this item.
+
+	 \returns a shared pointer to an immutable link destination
+      **/
+      QSharedPointer<const LinkDestination> destination() const;
+
+      /**
+	 The external file name of the document to which the \see destination refers
+
+	 \returns a string with the external file name or an empty string if there is none
+       */
+      QString externalFileName() const;
+
+      /**
+	 The URI to which the item links
+
+	 \returns a string with the URI which this item links or an empty string if there is none
+      **/
+      QString uri() const;
+
+      /**
+	 Determines if this item has any child items
+
+	 \returns true if there are any child items
+      **/
+      bool hasChildren() const;
+
+      /**
+	 Gets the child items of this item
+
+	 \returns a vector outline items, empty if there are none
+      **/
+      QVector<OutlineItem> children() const;
+
+    private:
+      OutlineItem(OutlineItemData *data);
+      OutlineItemData *m_data;
+    };
+
 /**
    \brief PDF document.
 
@@ -976,7 +1066,7 @@ delete it;
    \section ownership Ownership of the returned objects
 
    All the functions that returns class pointers create new object, and the
-   responsability of those is given to the callee.
+   responsibility of those is given to the callee.
 
    The only exception is \link Poppler::Page::transition() Page::transition()\endlink.
 
@@ -1014,7 +1104,7 @@ delete it;
 
    To know whether the %Poppler version you are using has support for color
    management, you can query Poppler::isCmsAvailable(). In case it is not
-   avilable, all the color management-related functions will either do nothing
+   available, all the color management-related functions will either do nothing
    or return null.
 */
     class POPPLER_QT5_EXPORT Document {
@@ -1091,6 +1181,8 @@ delete it;
 
 	  \param outputProfileA is a \c cmsHPROFILE of the LCMS library.
 
+	  \note This should be called before any rendering happens and only once during the lifetime of the current process.
+
 	   \since 0.12
 	*/
 	void setColorDisplayProfile(void *outputProfileA);
@@ -1099,6 +1191,8 @@ delete it;
 
 	  \param name is the name of the display profile to set.
 
+	  \note This should be called before any rendering happens.
+
 	   \since 0.12
 	*/
 	void setColorDisplayProfileName(const QString &name);
@@ -1535,7 +1629,7 @@ QString subject = m_doc->info("Subject");
 	/**
 	  Gets the table of contents (TOC) of the Document.
 	
-	  The caller is responsable for the returned object.
+	  The caller is responsible for the returned object.
 	
 	  In the tree the tag name is the 'screen' name of the entry. A tag can have
 	  attributes. Here follows the list of tag attributes with meaning:
@@ -1556,6 +1650,15 @@ QString subject = m_doc->info("Subject");
 	  \returns the TOC, or NULL if the Document does not have one
 	*/
 	QDomDocument *toc() const;
+
+	/**
+	   Gets the outline of the document
+
+	   \returns a vector of outline items, empty if there are none
+
+	   \since 0.74
+	**/
+	QVector<OutlineItem> outline() const;
 	
 	/**
 	   Tries to resolve the named destination \p name.
