@@ -17,12 +17,13 @@
 // Copyright (C) 2009 Stefan Thomas <thomas@eload24.com>
 // Copyright (C) 2010, 2017 Adrian Johnson <ajohnson@redneon.com>
 // Copyright (C) 2010 Harry Roberts <harry.roberts@midnight-labs.org>
-// Copyright (C) 2010 Christian Feuersnger <cfeuersaenger@googlemail.com>
+// Copyright (C) 2010 Christian Feuersänger <cfeuersaenger@googlemail.com>
 // Copyright (C) 2010 William Bader <williambader@hotmail.com>
 // Copyright (C) 2012 Thomas Freitag <Thomas.Freitag@alfa.de>
 // Copyright (C) 2015 Adam Reichold <adamreichold@myopera.com>
 // Copyright (C) 2016 Kenji Uno <ku@digitaldolphins.jp>
 // Copyright (C) 2018 Martin Packman <gzlist@googlemail.com>
+// Copyright (C) 2019 Oliver Sander <oliver.sander@tu-dresden.de>
 //
 // To see a description of the changes please see the Changelog file that
 // came with your tarball or type make ChangeLog if you are building from git
@@ -51,7 +52,7 @@ public:
   // upside-down, i.e., with the last row first in memory.
   SplashBitmap(int widthA, int heightA, int rowPad,
 	       SplashColorMode modeA, bool alphaA,
-	       bool topDown = true, GooList *separationList = nullptr);
+	       bool topDown = true, std::vector<GfxSeparationColorSpace*> *separationList = nullptr);
   static SplashBitmap *copy(SplashBitmap *src);
 
   ~SplashBitmap();
@@ -66,8 +67,8 @@ public:
   int getRowPad() { return rowPad; }
   SplashColorMode getMode() { return mode; }
   SplashColorPtr getDataPtr() { return data; }
-  Guchar *getAlphaPtr() { return alpha; }
-  GooList *getSeparationList() { return separationList; }
+  unsigned char *getAlphaPtr() { return alpha; }
+  std::vector<GfxSeparationColorSpace*> *getSeparationList() { return separationList; }
 
   SplashError writePNMFile(char *fileName);
   SplashError writePNMFile(FILE *f);
@@ -100,7 +101,7 @@ public:
 #ifdef SPLASH_CMYK
   void getCMYKLine(int y, SplashColorPtr line);
 #endif
-  Guchar getAlpha(int x, int y);
+  unsigned char getAlpha(int x, int y);
 
   // Caller takes ownership of the bitmap data.  The SplashBitmap
   // object is no longer valid -- the next call should be to the
@@ -115,9 +116,9 @@ private:
 				//   - negative for bottom-up bitmaps
   SplashColorMode mode;		// color mode
   SplashColorPtr data;		// pointer to row zero of the color data
-  Guchar *alpha;		// pointer to row zero of the alpha data
+  unsigned char *alpha;		// pointer to row zero of the alpha data
 				//   (always top-down)
-  GooList *separationList; // list of spot colorants and their mapping functions
+  std::vector<GfxSeparationColorSpace*> *separationList; // list of spot colorants and their mapping functions
 
   friend class Splash;
 
