@@ -15,6 +15,7 @@
 // Copyright (C) 2009 Petr Gajdos <pgajdos@novell.com>
 // Copyright (C) 2011 Andreas Hartmetz <ahartmetz@gmail.com>
 // Copyright (C) 2017 Adrian Johnson <ajohnson@redneon.com>
+// Copyright (C) 2018 Oliver Sander <oliver.sander@tu-dresden.de>
 //
 // To see a description of the changes please see the Changelog file that
 // came with your tarball or type make ChangeLog if you are building from git
@@ -26,10 +27,6 @@
 
 #include "poppler-config.h"
 
-#ifdef USE_GCC_PRAGMAS
-#pragma interface
-#endif
-
 #include <ft2build.h>
 #include FT_FREETYPE_H
 #include "SplashFont.h"
@@ -44,17 +41,17 @@ class SplashFTFont: public SplashFont {
 public:
 
   SplashFTFont(SplashFTFontFile *fontFileA, SplashCoord *matA,
-	       SplashCoord *textMatA);
+	       const SplashCoord *textMatA);
 
   virtual ~SplashFTFont();
 
   // Munge xFrac and yFrac before calling SplashFont::getGlyph.
-  GBool getGlyph(int c, int xFrac, int yFrac,
+  bool getGlyph(int c, int xFrac, int yFrac,
 		 SplashGlyphBitmap *bitmap, int x0, int y0, SplashClip *clip, SplashClipResult *clipRes) override;
 
   // Rasterize a glyph.  The <xFrac> and <yFrac> values are the same
   // as described for getGlyph.
-  GBool makeGlyph(int c, int xFrac, int yFrac,
+  bool makeGlyph(int c, int xFrac, int yFrac,
 		  SplashGlyphBitmap *bitmap, int x0, int y0, SplashClip *clip, SplashClipResult *clipRes) override;
 
   // Return the path for a glyph.
@@ -70,9 +67,9 @@ private:
   FT_Matrix textMatrix;
   SplashCoord textScale;
   int size;
-  GBool enableFreeTypeHinting;
-  GBool enableSlightHinting;
-  GBool isOk;
+  bool enableFreeTypeHinting;
+  bool enableSlightHinting;
+  bool isOk;
 };
 
 #endif
