@@ -16,6 +16,8 @@
 // Copyright (C) 2009, 2011-2013 Thomas Freitag <Thomas.Freitag@alfa.de>
 // Copyright (C) 2009 Stefan Thomas <thomas@eload24.com>
 // Copyright (C) 2010 William Bader <williambader@hotmail.com>
+// Copyright (C) 2017 Adrian Johnson <ajohnson@redneon.com>
+// Copyright (C) 2018 Stefan Brüns <stefan.bruens@rwth-aachen.de>
 //
 // To see a description of the changes please see the Changelog file that
 // came with your tarball or type make ChangeLog if you are building from git
@@ -25,16 +27,14 @@
 #ifndef SPLASHTYPES_H
 #define SPLASHTYPES_H
 
-#include "goo/gtypes.h"
-
 //------------------------------------------------------------------------
 // coordinates
 //------------------------------------------------------------------------
 
-#if USE_FIXEDPOINT
+#if defined(USE_FIXEDPOINT)
 #include "goo/FixedPoint.h"
 typedef FixedPoint SplashCoord;
-#elif USE_FLOAT
+#elif defined(USE_FLOAT)
 typedef float SplashCoord;
 #else
 typedef double SplashCoord;
@@ -46,11 +46,9 @@ typedef double SplashCoord;
 
 #define splashAASize 4
 
-#ifdef SPLASH_CMYK
 #ifndef SPOT_NCOMPS
 #define SPOT_NCOMPS 4
 #endif
-#endif
 
 //------------------------------------------------------------------------
 // colors
@@ -66,7 +64,7 @@ enum SplashColorMode {
 				//   BGRBGR...
   splashModeXBGR8		// 1 byte per component, 4 bytes per pixel:
 				//   XBGRXBGR...
-#if SPLASH_CMYK
+#ifdef SPLASH_CMYK
   ,
   splashModeCMYK8,	// 1 byte per component, 4 bytes per pixel:
 				//   CMYKCMYK...
@@ -87,47 +85,47 @@ enum SplashThinLineMode {
 extern int splashColorModeNComps[];
 
 // max number of components in any SplashColor
-#if SPLASH_CMYK
+#ifdef SPLASH_CMYK
 #define splashMaxColorComps SPOT_NCOMPS+4
 #else
 #define splashMaxColorComps 4
 #endif
 
-typedef Guchar SplashColor[splashMaxColorComps];
-typedef Guchar *SplashColorPtr;
+typedef unsigned char SplashColor[splashMaxColorComps];
+typedef unsigned char *SplashColorPtr;
 
 // RGB8
-static inline Guchar splashRGB8R(SplashColorPtr rgb8) { return rgb8[0]; }
-static inline Guchar splashRGB8G(SplashColorPtr rgb8) { return rgb8[1]; }
-static inline Guchar splashRGB8B(SplashColorPtr rgb8) { return rgb8[2]; }
+static inline unsigned char splashRGB8R(SplashColorPtr rgb8) { return rgb8[0]; }
+static inline unsigned char splashRGB8G(SplashColorPtr rgb8) { return rgb8[1]; }
+static inline unsigned char splashRGB8B(SplashColorPtr rgb8) { return rgb8[2]; }
 
 // BGR8
-static inline Guchar splashBGR8R(SplashColorPtr bgr8) { return bgr8[2]; }
-static inline Guchar splashBGR8G(SplashColorPtr bgr8) { return bgr8[1]; }
-static inline Guchar splashBGR8B(SplashColorPtr bgr8) { return bgr8[0]; }
+static inline unsigned char splashBGR8R(SplashColorPtr bgr8) { return bgr8[2]; }
+static inline unsigned char splashBGR8G(SplashColorPtr bgr8) { return bgr8[1]; }
+static inline unsigned char splashBGR8B(SplashColorPtr bgr8) { return bgr8[0]; }
 
-#if SPLASH_CMYK
+#ifdef SPLASH_CMYK
 // CMYK8
-static inline Guchar splashCMYK8C(SplashColorPtr cmyk8) { return cmyk8[0]; }
-static inline Guchar splashCMYK8M(SplashColorPtr cmyk8) { return cmyk8[1]; }
-static inline Guchar splashCMYK8Y(SplashColorPtr cmyk8) { return cmyk8[2]; }
-static inline Guchar splashCMYK8K(SplashColorPtr cmyk8) { return cmyk8[3]; }
+static inline unsigned char splashCMYK8C(SplashColorPtr cmyk8) { return cmyk8[0]; }
+static inline unsigned char splashCMYK8M(SplashColorPtr cmyk8) { return cmyk8[1]; }
+static inline unsigned char splashCMYK8Y(SplashColorPtr cmyk8) { return cmyk8[2]; }
+static inline unsigned char splashCMYK8K(SplashColorPtr cmyk8) { return cmyk8[3]; }
 
 // DEVICEN8
-static inline Guchar splashDeviceN8C(SplashColorPtr deviceN8) { return deviceN8[0]; }
-static inline Guchar splashDeviceN8M(SplashColorPtr deviceN8) { return deviceN8[1]; }
-static inline Guchar splashDeviceN8Y(SplashColorPtr deviceN8) { return deviceN8[2]; }
-static inline Guchar splashDeviceN8K(SplashColorPtr deviceN8) { return deviceN8[3]; }
-static inline Guchar splashDeviceN8S(SplashColorPtr deviceN8, int nSpot) { return deviceN8[4 + nSpot]; }
+static inline unsigned char splashDeviceN8C(SplashColorPtr deviceN8) { return deviceN8[0]; }
+static inline unsigned char splashDeviceN8M(SplashColorPtr deviceN8) { return deviceN8[1]; }
+static inline unsigned char splashDeviceN8Y(SplashColorPtr deviceN8) { return deviceN8[2]; }
+static inline unsigned char splashDeviceN8K(SplashColorPtr deviceN8) { return deviceN8[3]; }
+static inline unsigned char splashDeviceN8S(SplashColorPtr deviceN8, int nSpot) { return deviceN8[4 + nSpot]; }
 #endif
 
 static inline void splashClearColor(SplashColorPtr dest) {
   dest[0] = 0;
   dest[1] = 0;
   dest[2] = 0;
-#if SPLASH_CMYK
+#ifdef SPLASH_CMYK
   dest[3] = 0;
-  for (int i = SPOT_NCOMPS; i < SPOT_NCOMPS + 4; i++)
+  for (int i = 4; i < SPOT_NCOMPS + 4; i++)
     dest[i] = 0;
 #endif
 }
@@ -136,9 +134,9 @@ static inline void splashColorCopy(SplashColorPtr dest, SplashColorPtr src) {
   dest[0] = src[0];
   dest[1] = src[1];
   dest[2] = src[2];
-#if SPLASH_CMYK
+#ifdef SPLASH_CMYK
   dest[3] = src[3];
-  for (int i = SPOT_NCOMPS; i < SPOT_NCOMPS + 4; i++)
+  for (int i = 4; i < SPOT_NCOMPS + 4; i++)
     dest[i] = src[i];
 #endif
 }
@@ -147,9 +145,9 @@ static inline void splashColorXor(SplashColorPtr dest, SplashColorPtr src) {
   dest[0] ^= src[0];
   dest[1] ^= src[1];
   dest[2] ^= src[2];
-#if SPLASH_CMYK
+#ifdef SPLASH_CMYK
   dest[3] ^= src[3];
-  for (int i = SPOT_NCOMPS; i < SPOT_NCOMPS + 4; i++)
+  for (int i = 4; i < SPOT_NCOMPS + 4; i++)
     dest[i] ^= src[i];
 #endif
 }
