@@ -11,7 +11,7 @@
 // All changes made under the Poppler project to this file are licensed
 // under GPL version 2 or later
 //
-// Copyright (C) 2008, 2010, 2014, 2018 Albert Astals Cid <aacid@kde.org>
+// Copyright (C) 2008, 2010, 2014, 2018, 2019 Albert Astals Cid <aacid@kde.org>
 // Copyright (C) 2010 Paweł Wiejacha <pawel.wiejacha@gmail.com>
 // Copyright (C) 2013, 2014 Thomas Freitag <Thomas.Freitag@alfa.de>
 // Copyright (C) 2018 Stefan Brüns <stefan.bruens@rwth-aachen.de>
@@ -356,7 +356,7 @@ void SplashXPathScanner::renderAALine(SplashBitmap *aaBuf,
 				      int *x0, int *x1, int y, bool adjustVertLine) {
   int xx0, xx1, xx, xxMin, xxMax, yy, yyMax, interCount;
   size_t interIdx;
-  Guchar mask;
+  unsigned char mask;
   SplashColorPtr p;
 
   memset(aaBuf->getDataPtr(), 0, aaBuf->getRowSize() * aaBuf->getHeight());
@@ -405,7 +405,7 @@ void SplashXPathScanner::renderAALine(SplashBitmap *aaBuf,
 	  if (xx & 7) {
 	    mask = adjustVertLine ? 0xff : 0xff >> (xx & 7);
 	    if (!adjustVertLine && (xx & ~7) == (xx1 & ~7)) {
-	      mask &= (Guchar)(0xff00 >> (xx1 & 7));
+	      mask &= (unsigned char)(0xff00 >> (xx1 & 7));
 	    }
 	    *p++ |= mask;
 	    xx = (xx & ~7) + 8;
@@ -414,7 +414,7 @@ void SplashXPathScanner::renderAALine(SplashBitmap *aaBuf,
 	    *p++ |= 0xff;
 	  }
 	  if (xx < xx1) {
-	    *p |= adjustVertLine ? 0xff : (Guchar)(0xff00 >> (xx1 & 7));
+	    *p |= adjustVertLine ? 0xff : (unsigned char)(0xff00 >> (xx1 & 7));
 	  }
 	}
 	if (xx0 < xxMin) {
@@ -437,7 +437,7 @@ void SplashXPathScanner::clipAALine(SplashBitmap *aaBuf,
 				    int *x0, int *x1, int y) {
   int xx0, xx1, xx, yy, yyMin, yyMax, interCount;
   size_t interIdx;
-  Guchar mask;
+  unsigned char mask;
   SplashColorPtr p;
 
   yyMin = 0;
@@ -452,7 +452,10 @@ void SplashXPathScanner::clipAALine(SplashBitmap *aaBuf,
   for (yy = 0; yy < splashAASize; ++yy) {
     xx = *x0 * splashAASize;
     if (yy >= yyMin && yy <= yyMax) {
-      const auto& line = allIntersections[splashAASize * y + yy - yMin];
+      const int intersectionIndex = splashAASize * y + yy - yMin;
+      if (unlikely(intersectionIndex < 0 || (unsigned)intersectionIndex >= allIntersections.size()))
+	break;
+      const auto& line = allIntersections[intersectionIndex];
       interIdx = 0;
       interCount = 0;
       while (interIdx < line.size() && xx < (*x1 + 1) * splashAASize) {
@@ -476,7 +479,7 @@ void SplashXPathScanner::clipAALine(SplashBitmap *aaBuf,
 	if (xx < xx0) {
 	  p = aaBuf->getDataPtr() + yy * aaBuf->getRowSize() + (xx >> 3);
 	  if (xx & 7) {
-	    mask = (Guchar)(0xff00 >> (xx & 7));
+	    mask = (unsigned char)(0xff00 >> (xx & 7));
 	    if ((xx & ~7) == (xx0 & ~7)) {
 	      mask |= 0xff >> (xx0 & 7);
 	    }
@@ -501,7 +504,7 @@ void SplashXPathScanner::clipAALine(SplashBitmap *aaBuf,
     if (xx < xx0 && xx >= 0) {
       p = aaBuf->getDataPtr() + yy * aaBuf->getRowSize() + (xx >> 3);
       if (xx & 7) {
-	mask = (Guchar)(0xff00 >> (xx & 7));
+	mask = (unsigned char)(0xff00 >> (xx & 7));
 	if ((xx & ~7) == (xx0 & ~7)) {
 	  mask &= 0xff >> (xx0 & 7);
 	}
