@@ -13,7 +13,7 @@
 // All changes made under the Poppler project to this file are licensed
 // under GPL version 2 or later
 //
-// Copyright (C) 2005, 2007, 2011, 2018 Albert Astals Cid <aacid@kde.org>
+// Copyright (C) 2005, 2007, 2011, 2018, 2019 Albert Astals Cid <aacid@kde.org>
 // Copyright (C) 2006 Rainer Keller <class321@gmx.de>
 // Copyright (C) 2008 Timothy Lee <timothy.lee@siriushk.com>
 // Copyright (C) 2008 Vasile Gaburici <gaburici@cs.umd.edu>
@@ -354,11 +354,11 @@ void ImageOutputDev::writeImageFile(ImgWriter *writer, ImageFormat format, const
   ImageStream *imgStr = nullptr;
   unsigned char *row;
   unsigned char *rowp;
-  Guchar *p;
+  unsigned char *p;
   GfxRGB rgb;
   GfxCMYK cmyk;
   GfxGray gray;
-  Guchar zero[gfxColorMaxComps];
+  unsigned char zero[gfxColorMaxComps];
   int invert_bits;
 
   if (writer) {
@@ -428,7 +428,7 @@ void ImageOutputDev::writeImageFile(ImgWriter *writer, ImageFormat format, const
 
     case imgRGB48: {
       p = imgStr->getLine();
-      Gushort *rowp16 = (Gushort*)row;
+      unsigned short *rowp16 = reinterpret_cast<unsigned short*>(row);
       for (int x = 0; x < width; ++x) {
 	if (p) {
 	  colorMap->getRGB(p, &rgb);
