@@ -348,12 +348,12 @@ int main(int argc, char *argv[]) {
   if (argc == 3) {
     psFileName = new GooString(argv[2]);
   } else if (fileName->cmp("fd://0") == 0) {
-    error(errCommandLine, -1, "You have to provide an output filename when reading form stdin.");
+    error(errCommandLine, -1, "You have to provide an output filename when reading from stdin.");
     goto err1;
   } else {
-    const char *p = fileName->getCString() + fileName->getLength() - 4;
+    const char *p = fileName->c_str() + fileName->getLength() - 4;
     if (!strcmp(p, ".pdf") || !strcmp(p, ".PDF")) {
-      psFileName = new GooString(fileName->getCString(),
+      psFileName = new GooString(fileName->c_str(),
 			       fileName->getLength() - 4);
     } else {
       psFileName = fileName->copy();
@@ -386,7 +386,7 @@ int main(int argc, char *argv[]) {
   }
 
   // write PostScript file
-  psOut = new PSOutputDev(psFileName->getCString(), doc,
+  psOut = new PSOutputDev(psFileName->c_str(), doc,
 			  nullptr, pages, mode,
 			  paperWidth,
 			  paperHeight,
